# simple-dag

A simple DAG implementation. Intended to be a bare-bones version of the API provided by NetworkX implementing all of the features needed to model a data processing pipeline.

Multiple edges between the same two nodes are not supported, and attempts to add multiple edges between the same two nodes are ignored.